@@ -111,7 +111,7 @@ sub run {
 
     my $location = Mojo::URL->new( $t->tx->res->headers->location );
     note $location->fragment;
-    ok( my ( $access_token ) = ( $location->fragment =~ qr/access_token=(.*?).token_type/ ),'includes token' );
+    ok( my ( $access_token ) = ( $location->fragment =~ qr/access_token=([^&]*)/ ),'includes token' );
 
     note( "don't use access token to access route" );
     $t->get_ok('/api/eat')->status_is( 401 );
